==> kmud-0.5.tar.gz: kmud-0.5/kmud/dialogs/dlgmaproomapperance.cpp <==
/***************************************************************************
                          dlgmaproomapperance.cpp  -  description
                             -------------------
    begin                : Fri Sep 22 2000
    copyright            : (C) 2000 by John-Paul Stanford
    email                : john-paul.stanford@virgin.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dlgmaproomapperance.h"

DlgMapRoomApperance::DlgMapRoomApperance(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
	
	connect (optDefaultCol,SIGNAL(clicked()),SLOT(slotUseDefaultColClicked()));
}

DlgMapRoomApperance::~DlgMapRoomApperance()
{
}

QColor DlgMapRoomApperance::getColour(void)
{ return cmdColour->color(); }


void DlgMapRoomApperance::setColour(QColor colour)
{ cmdColour->setColor(colour); }

void DlgMapRoomApperance::setUseDefaultCol(bool b)
{
	optDefaultCol->setChecked(b);
	cmdColour->setEnabled(!optDefaultCol->isChecked());
}

bool DlgMapRoomApperance::getUseDefaultCol(void)
{ return optDefaultCol->isChecked(); }

void DlgMapRoomApperance::slotUseDefaultColClicked(void)
{
	cmdColour->setEnabled(!optDefaultCol->isChecked());
}

==> kmud-1.0.tar.gz: kmud-1.0/kmud/dialogs/dlgmaproomapperance.cpp <==
/***************************************************************************
                          dlgmaproomapperance.cpp  -  description
                             -------------------
    begin                : Fri Sep 22 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dlgmaproomapperance.h"

DlgMapRoomApperance::DlgMapRoomApperance(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
	
	connect (optDefaultCol,SIGNAL(clicked()),SLOT(slotUseDefaultColClicked()));
}

DlgMapRoomApperance::~DlgMapRoomApperance()
{
}

QColor DlgMapRoomApperance::getColour(void)
{ return cmdColour->color(); }


void DlgMapRoomApperance::setColour(QColor colour)
{ cmdColour->setColor(colour); }

void DlgMapRoomApperance::setUseDefaultCol(bool b)
{
	optDefaultCol->setChecked(b);
	cmdColour->setEnabled(!optDefaultCol->isChecked());
}

bool DlgMapRoomApperance::getUseDefaultCol(void)
{ return optDefaultCol->isChecked(); }

void DlgMapRoomApperance::slotUseDefaultColClicked(void)
{
	cmdColour->setEnabled(!optDefaultCol->isChecked());
}
